@@ -9,6 +9,7 @@ from io import StringIO
 from pathlib import Path
 from shutil import copyfile
 from typing import Any, Generator, Optional, Tuple, Union
+from unittest import mock
 
 import pytest
 
@@ -69,8 +70,8 @@ def run_codespell(
 ) -> int:
     """Run codespell."""
     args = tuple(str(arg) for arg in args)
-    proc = subprocess.run(
-        ["codespell", "--count", *args],  # noqa: S603, S607
+    proc = subprocess.run(  # noqa: S603
+        ["codespell", "--count", *args],  # noqa: S607
         cwd=cwd,
         capture_output=True,
         encoding="utf-8",
@@ -208,12 +209,12 @@ def test_permission_error(
     fname.write_text("abandonned\n")
     result = cs.main(fname, std=True)
     assert isinstance(result, tuple)
-    code, _, stderr = result
+    _, _, stderr = result
     assert "WARNING:" not in stderr
     fname.chmod(0o000)
     result = cs.main(fname, std=True)
     assert isinstance(result, tuple)
-    code, _, stderr = result
+    _, _, stderr = result
     assert "WARNING:" in stderr
 
 
@@ -229,9 +230,11 @@ def test_interactivity(
     try:
         assert cs.main(fname) == 0, "empty file"
         fname.write_text("abandonned\n")
-        assert cs.main("-i", "-1", fname) == 1, "bad"
-        with FakeStdin("y\n"):
-            assert cs.main("-i", "3", fname) == 1
+        with mock.patch.object(sys, "argv", ("-i", "-1", fname)):
+            with pytest.raises(SystemExit) as e:
+                cs.main("-i", "-1", fname)
+            assert e.type is SystemExit
+            assert e.value.code != 0
         with FakeStdin("n\n"):
             result = cs.main("-w", "-i", "3", fname, std=True)
             assert isinstance(result, tuple)
@@ -357,9 +360,7 @@ def test_ignore_words_with_cases(
     """Test case-sensitivity implemented for -I and -L options in #3272."""
     bad_name = tmp_path / "MIS.txt"
     bad_name.write_text(
-        "1 MIS (Management Information System) 1\n"
-        "2 Les Mis (1980 musical) 2\n"
-        "3 mis 3\n"
+        "1 MIS (Management Information System) 1\n2 Les Mis (1980 musical) 2\n3 mis 3\n"
     )
     assert cs.main(bad_name) == 3
     assert cs.main(bad_name, "-f") == 4
@@ -453,7 +454,7 @@ def test_inline_ignores(
     expected_error_count: int,
 ) -> None:
     d = str(tmpdir)
-    with open(op.join(d, "bad.txt"), "w") as f:
+    with open(op.join(d, "bad.txt"), "w", encoding="utf-8") as f:
         f.write(content)
     assert cs.main(d) == expected_error_count
 
@@ -761,7 +762,7 @@ def _helper_test_case_handling_in_fixes(
     fname.write_text("early adoptor\n")
     result = cs.main("-D", dictionary_name, fname, std=True)
     assert isinstance(result, tuple)
-    code, stdout, _ = result
+    _, stdout, _ = result
     # all suggested fixes must be lowercase too
     assert "adopter, adaptor" in stdout
     # the reason, if any, must not be modified
@@ -772,7 +773,7 @@ def _helper_test_case_handling_in_fixes(
     fname.write_text("Early Adoptor\n")
     result = cs.main("-D", dictionary_name, fname, std=True)
     assert isinstance(result, tuple)
-    code, stdout, _ = result
+    _, stdout, _ = result
     # all suggested fixes must be capitalized too
     assert "Adopter, Adaptor" in stdout
     # the reason, if any, must not be modified
@@ -783,7 +784,7 @@ def _helper_test_case_handling_in_fixes(
     fname.write_text("EARLY ADOPTOR\n")
     result = cs.main("-D", dictionary_name, fname, std=True)
     assert isinstance(result, tuple)
-    code, stdout, _ = result
+    _, stdout, _ = result
     # all suggested fixes must be uppercase too
     assert "ADOPTER, ADAPTOR" in stdout
     # the reason, if any, must not be modified
@@ -794,7 +795,7 @@ def _helper_test_case_handling_in_fixes(
     fname.write_text("EaRlY AdOpToR\n")
     result = cs.main("-D", dictionary_name, fname, std=True)
     assert isinstance(result, tuple)
-    code, stdout, _ = result
+    _, stdout, _ = result
     # all suggested fixes should be lowercase
     assert "adopter, adaptor" in stdout
     # the reason, if any, must not be modified
@@ -805,7 +806,7 @@ def _helper_test_case_handling_in_fixes(
 def test_case_handling_in_fixes(
     tmp_path: Path, capsys: pytest.CaptureFixture[str]
 ) -> None:
-    """Test that the case of fixes is similar to the mispelled word."""
+    """Test that the case of fixes is similar to the misspelled word."""
     _helper_test_case_handling_in_fixes(tmp_path, capsys, reason=False)
     _helper_test_case_handling_in_fixes(tmp_path, capsys, reason=True)
 
@@ -929,6 +930,43 @@ def test_ignore_regex_option(
     assert cs.main(fname, r"--ignore-regex=\bdonn\b") == 1
 
 
+def test_ignore_multiline_regex_option(
+    tmp_path: Path,
+    capsys: pytest.CaptureFixture[str],
+) -> None:
+    """Test ignore regex option functionality."""
+
+    # Invalid regex.
+    result = cs.main("--ignore-multiline-regex=(", std=True)
+    assert isinstance(result, tuple)
+    code, stdout, _ = result
+    assert code == EX_USAGE
+    assert "usage:" in stdout
+
+    fname = tmp_path / "flag.txt"
+    fname.write_text(
+        """
+        Please see http://example.com/abandonned for info
+        # codespell:ignore-begin
+        '''
+        abandonned
+        abandonned
+        '''
+        # codespell:ignore-end
+        abandonned
+        """
+    )
+    assert cs.main(fname) == 4
+    assert (
+        cs.main(
+            fname,
+            "--ignore-multiline-regex",
+            "codespell:ignore-begin.*codespell:ignore-end",
+        )
+        == 2
+    )
+
+
 def test_uri_regex_option(
     tmp_path: Path,
     capsys: pytest.CaptureFixture[str],
@@ -1186,7 +1224,7 @@ def test_quiet_level_32(
     d = tmp_path / "files"
     d.mkdir()
     conf = str(tmp_path / "setup.cfg")
-    with open(conf, "w") as f:
+    with open(conf, "w", encoding="utf-8") as f:
         # It must contain a "codespell" section.
         f.write("[codespell]\n")
     args = ("--config", conf)
@@ -1215,7 +1253,7 @@ def test_ill_formed_ini_config_file(
     d = tmp_path / "files"
     d.mkdir()
     conf = str(tmp_path / "setup.cfg")
-    with open(conf, "w") as f:
+    with open(conf, "w", encoding="utf-8") as f:
         # It should contain but lacks a section.
         f.write("foobar =\n")
     args = ("--config", conf)
@@ -1331,8 +1369,8 @@ def run_codespell_stdin(
     cwd: Optional[Path] = None,
 ) -> int:
     """Run codespell in stdin mode and return number of lines in output."""
-    proc = subprocess.run(
-        ["codespell", *args, "-"],  # noqa: S603, S607
+    proc = subprocess.run(  # noqa: S603
+        ["codespell", *args, "-"],  # noqa: S607
         cwd=cwd,
         input=text,
         capture_output=True,
